use OSSRegistrations;

create table conferences(
		confname varchar(64),
		longname varchar(256),
		confdate datetime,
		regstart datetime,
		regend	 datetime,
		beforetext varchar(256),
		aftertext  varchar(256),
		locked   integer,
		primary key(confname)
);

create table conferenceslog(
		conflogno	integer NOT NULL auto_increment,
		confname varchar(64),
		longname varchar(256),
		confdate datetime,
		regstart datetime,
		regend	 datetime,
		beforetext varchar(256),
		aftertext  varchar(256),
		locked   integer,
		posttime			datetime,
		user					varchar(80),
		primary key(conflogno)
);

create table options(
	boxid				varchar(30),
	optionno		integer,
	optionval		varchar(30),
	optionname	varchar(30),

	primary key (boxid,optionno)
	 
);

/*
   
   Field no is the sorted number of the fields i.e. processing order of the form
   Field name is the registered PHP name of the field used to retrieve the information
   Field type is the type of the field i.e. text,dropdown,check,radio etc
   Field text is the written text for the field
   Field size is the byte size of the field or the number of options in option box
   Field span is the span of the column in columns
   Field width is the width of the column in percent

   Field ref is a reference to a field specific external table e.g. for menu alternatives
   Field verify is the name of the verification javascript that handles output/verification of entry

   Form name is the name of the form which is used to differentiate between forms   
   
   ----------------------------
   
   Field Types
   		1 Heading
   		2 Heading End
   		3 TableStart
   		4	TableEnd
			5 Row Start
			6 Row End
   		7 Text Field
   		8 Select Box
   		9 Spacer / Placeholder / Label
   		10 Radio Button
   		11 Locked Computation Field
   		12 Check Box
   		13 Line
   		14 Footnote
   		15 Image
   
   "Heading" is a special kind of element that starts and ends individual parts of the form
   "Table start" and "table end" allows start and end of the table to change the number of columns within the main form
   "Row start" and "row end" marks the start and end position of the table rows
   "Footnote" can be repeated if multiple lines are required. This is printed without the table elements.
   
*/

create table fieldtypes(
		fieldtype			integer,
		typename			varchar(40),
		primary key(fieldtype)
);

insert into fieldtypes (fieldtype,typename) values ("1","Box Heading Start");
insert into fieldtypes (fieldtype,typename) values ("2","Box Heading End");
insert into fieldtypes (fieldtype,typename) values ("3","Table Start");
insert into fieldtypes (fieldtype,typename) values ("4","Table End");
insert into fieldtypes (fieldtype,typename) values ("5","Row Start");
insert into fieldtypes (fieldtype,typename) values ("6","Row End");
insert into fieldtypes (fieldtype,typename) values ("7","Text Field");
insert into fieldtypes (fieldtype,typename) values ("8","Select Option Box");
insert into fieldtypes (fieldtype,typename) values ("9","Placeholder");
insert into fieldtypes (fieldtype,typename) values ("10","Radio Button");
insert into fieldtypes (fieldtype,typename) values ("11","Locked Computation Box");
insert into fieldtypes (fieldtype,typename) values ("12","Checkbox");
insert into fieldtypes (fieldtype,typename) values ("13","Line");
insert into fieldtypes (fieldtype,typename) values ("14","Footnote");
insert into fieldtypes (fieldtype,typename) values ("15","Image");

create table fields(
		fieldno 			integer NOT NULL auto_increment,
		fieldsort			integer,
		fieldname   	varchar(30),
		fieldtype   	integer,
		fieldtext			varchar(512),
		fieldsize   	integer,
		fieldspan			integer,
		fieldrowspan	integer,
		fieldwidth		varchar(10),
		fieldcolor		varchar(8),
		fielddef      varchar(60),
		fieldalign		varchar(8),
		fieldref			varchar(16),
		fieldverify		varchar(256),
		fieldmandatory integer,
		formname    	varchar(20),
		primary key (fieldno)
);

create table fieldslog(logid integer NOT NULL auto_increment,fieldno integer,fieldsort integer,fieldname varchar(30),fieldtype integer,fieldtext varchar(512),fieldsize integer,fieldspan integer,fieldrowspan integer,fieldwidth varchar(10),fieldcolor varchar(8),fielddef varchar(60),fieldalign varchar(8),fieldref varchar(16),fieldverify varchar(256),formname varchar(20),fieldmandatory integer,posttime datetime,user varchar(80),primary key (logid));

CREATE TABLE personal(
  PID integer NOT NULL auto_increment,
  firstname varchar(40),
  lastname varchar(40),
  posttime timestamp,
  persemail varchar(80),
  pw varchar(25),
  kind int(11),
  conferences varchar(256),
  last_ip varchar(15) DEFAULT NULL,
  PRIMARY KEY  (PID)
);

CREATE TABLE personallog(
  PLOGID integer NOT NULL auto_increment,
	PID integer,
  firstname varchar(40),
  lastname varchar(40),
  posttime timestamp,
  persemail varchar(80),
  pw varchar(25),
  kind int(11),
  conferences varchar(256),
	logposttime			datetime,
	user					varchar(80),
  PRIMARY KEY  (PLOGID)
);

/*

		cardname and formname indicate the name of the form and the name of the corresponding card specification
		background is the url to the background of the card. This can be either a pixel image or an svg image uploaded to the server
		width is the width in cm for the card
		height is the height in cm for the card
		columncount is the number of columns of cards
		rowcount is the number of rows on each page in the printout
		borderwidth is the width in pixels of the border of the card
		marginwidth is the width of the inner margin on the card
		bordercolor is the color of the border either as a number or as a colorname
		borderkind is the type of border		

Text Template:

	E-mail Confirmation
	Submission Confirmation
	Other confirmation or mass-email?

   Layout Types
   		1 Block Start
   		2 Block End
   		3 Field
   		4	Image
			5 Text
			6 Line
   		7 Newline

*/

create table cards(
		cardno 			integer NOT NULL auto_increment,
		cardtype		integer,
		cardname		varchar(20),
		formname    varchar(20),
		background	varchar(64), 
		width 			integer,
		height			integer,
		columncount	integer,
		rowcount		integer,
		borderwidth	integer,
		marginwidth	integer,
		bordercolor varchar(32),
		borderkind	varchar(32),
		primary key (cardno)
);

insert into cards (cardtype,cardname,formname,background,width,height,columncount,rowcount,borderwidth,marginwidth,bordercolor,borderkind) values ("1","NameTag","OSS2009REG","PrintBack.png","9","6","2","3","1","4","#0099cc","dotted");
insert into cards (cardtype,cardname,formname) values ("2","RegConfirm","SUSU2010");
insert into cards (cardtype,cardname,formname,background,width,height,columncount,rowcount,borderwidth,marginwidth,bordercolor,borderkind) values ("1","NameTag","SUSU2010","test.png","9","6","2","3","1","4","#0099cc","solid");

create table cardslog(
		logno 			integer NOT NULL auto_increment,
		cardno 			integer,
		cardtype		integer,
		cardname		varchar(20),
		formname    varchar(20),
		background	varchar(64), 
		width 			integer,
		height			integer,
		columncount	integer,
		rowcount		integer,
		borderwidth	integer,
		marginwidth	integer,
		bordercolor varchar(32),
		borderkind	varchar(32),
		posttime			datetime,
		user					varchar(80),
		primary key (logno)
);

/*

   
   ----------------------------
   
   Layout Types
   		1 Block Start
   		2 Block End
   		3 Field
   		4	Image
			5 Text
			6 Line
   		7 Newline
   
	Blocks are divs 
	
	alignment			Alignment Left, Right, Center
	color					Color value or name for example #0077cc or Lightblue
	font					Font family name
	size					Size name or pixels
	breaking			Yes / No to nbsp break the text or not
	parameter			fieldname/value/text
	check					Check if statement
	otherwise			Otherwise statement
	clear					Check comparison value
	
	For email newline is \n for other kind of template the newline is <br>
	in email the line is --------------------------------- for other kinds of content the line is <hr>
	
	Perhaps card layout can encompass all kinds of templates?
	
	Conference links to confirmation template?
	
*/

create table cardlayouttypes(
		fieldtype			integer,
		typename			varchar(40),
		primary key(fieldtype)
);

insert into cardlayouttypes (fieldtype,typename) values ("1","Block Start");
insert into cardlayouttypes (fieldtype,typename) values ("2","Block End");
insert into cardlayouttypes (fieldtype,typename) values ("3","Field");
insert into cardlayouttypes (fieldtype,typename) values ("4","Image");
insert into cardlayouttypes (fieldtype,typename) values ("5","Text");
insert into cardlayouttypes (fieldtype,typename) values ("6","Line");
insert into cardlayouttypes (fieldtype,typename) values ("7","Newline");
insert into cardlayouttypes (fieldtype,typename) values ("8","Formtext");
insert into cardlayouttypes (fieldtype,typename) values ("9","Paylink");

create table cardlayout(
		layoutno 		integer NOT NULL auto_increment,
		cardname		varchar(20),
		formname    varchar(20),
		cardsort		integer,
		type				integer,
		alignment		varchar(16),
		color       varchar(32),
		font        varchar(32),
		size        varchar(32),
		breaking    integer,
		param   		varchar(256),
		cond   			varchar(64),
		otherwise   varchar(64),
		clear				varchar(64),
		
		primary key (layoutno)
);

create table cardlayoutlog(
		layoutlogno 		integer NOT NULL auto_increment,
		layoutno		integer,
		cardname		varchar(20),
		formname    varchar(20),
		cardsort		integer,
		type				integer,
		alignment		varchar(16),
		color       varchar(32),
		font        varchar(32),
		size        varchar(32),
		breaking    integer,
		param   		varchar(256),
		cond   			varchar(64),
		otherwise   varchar(64),
		clear				varchar(64),

		posttime			datetime,
		user					varchar(80),
		
		primary key (layoutlogno)
);

create table imgurl(
		imgno 		integer NOT NULL auto_increment,
		url				varchar(256),
		name			varchar(48),
		primary key (imgno)
);


