// Load the Google data JavaScript client library.
google.load('gdata', '2.x', {packages: ['analytics']});

// Set the callback function when the library is ready.
google.setOnLoadCallback(init);
var tableId = "";
var lastFuncCall;
var returnFunction = getDataFeedVisit;
/**
 * This is called once the Google Data JavaScript library has been loaded.
 * It creates a new AnalyticsService object, adds a click handler to the
 * authentication button and updates the button text depending on the status.
 */
function init() {
  myService = new google.gdata.analytics.AnalyticsService('gaExportAPI_acctSample_v2.0');
  scope = 'https://www.google.com/analytics/feeds';
  var button = document.getElementById('authButton');

  // Add a click handler to the Authentication button.
  button.onclick = function() {
    // Test if the user is not authenticated.
    if (!google.accounts.user.checkLogin(scope)) {
      // Authenticate the user.
      google.accounts.user.login(scope);
    } else {
      // Log the user out.
      google.accounts.user.logout();
      getStatus();
    }
  }
  setDate();
  getStatus();
}

function setDate()
{
	var start = document.getElementById("startDate");
	var end = document.getElementById("endDate");
	var date = new Date();
	var curr_date = date.getDate();
	if(curr_date<10)
		curr_date = "0"+curr_date;
	var curr_month = date.getMonth() + 1;
	if(curr_month<10)
		curr_month = "0"+curr_month;
	var curr_year = date.getFullYear();	
	var endVal = curr_year + "-" + curr_month + "-" + curr_date;
	var startVal = curr_year + "-" + curr_month + "-01";
	start.value = startVal;
	end.value = endVal;
}
function getStartDate()
{
	var start = document.getElementById("startDate");
	return start.value;
}
function getEndDate()
{
	var end = document.getElementById("endDate");
	return end.value;
}
function dateChanged()
{
	returnFunction();
}
/**
 * Utility method to display the user controls if the user is 
 * logged in. If user is logged in, get Account data and
 * get Report Data buttons are displayed.
 */
function getStatus() {
  //var getAccountButton = document.getElementById('getAccount');
  //getAccountButton.onclick = getAccountFeed;
  
  //var getDataButton = document.getElementById('getData');
  //getDataButton.onclick = getDataFeed;

  var dataControls = document.getElementById('dataControls');
  var loginButton = document.getElementById('authButton');
  if (!google.accounts.user.checkLogin(scope)) {
    dataControls.style.display = 'none';   // hide control div
    loginButton.innerHTML = 'Access Google Analytics';
  } else {
    dataControls.style.display = 'block';  // show control div
    loginButton.innerHTML = 'Logout';
	
	//Call account function
	getAccountFeed();
  }
}

/**
 * Main method to get account data from the API.
 */
function getAccountFeed() {
  var myFeedUri =
      'https://www.google.com/analytics/feeds/accounts/default?max-results=50';
  myService.getAccountFeed(myFeedUri, handleAccountFeed, handleError);
}

/**
 * Handle the account data returned by the Export API by constructing the inner parts
 * of an HTML table and inserting into the HTML file.
 * @param {object} result Parameter passed back from the feed handler.
 */
function handleAccountFeed(result) {
  // An array of analytics feed entries.
  var entries = result.feed.getEntries();

  changeHeading("Choose report");
  // Create an HTML Table using an array of elements.
  var outputTable = ['<table><tr>',
                     '<th>Account Name</th>',
                     '<th>Profile Name</th>',
                     '<th>Profile ID</th>',
                     '<th>Table Id</th></tr>'];

  // Iterate through the feed entries and add the data as table rows.
  for (var i = 0, entry; entry = entries[i]; ++i) {
    // Add a row in the HTML Table array for each value.
    var row = [
      entry.getPropertyValue('ga:AccountName'),
      entry.getTitle().getText(),
      entry.getPropertyValue('ga:ProfileId'),
      entry.getTableId().getValue()
    ].join('</td><td>');
	changeHeading(entry.getPropertyValue('ga:AccountName'));
	tableId = entry.getTableId().getValue();
	
    outputTable.push('<tr onclick=\"getDataFeedVisit();\"><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // Insert the table into the UI.
  document.getElementById('outputDiv').innerHTML =
      outputTable.join('');
}

function changeHeading(text)
{
var heading = document.getElementById("analyticHeading");
heading.innerHTML = text;
}

/**
 * Main method to get report data from the Export API.
 */
function getDataFeed() {
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date=' + getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:pageTitle,ga:pagePath' +
    '&metrics=ga:pageviews' +
    '&sort=-ga:pageviews' +
    '&max-results=10' +
    '&ids=' + tableId;
}

function getDataFeedVisit()
{
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date='+ getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:date' +
    '&metrics=ga:visits,ga:pageviews,ga:visitors,ga:newVisits' +
    '&sort=ga:date' +
    '&ids=' + tableId;
	returnFunction = getDataFeedVisit;
	myService.getDataFeed(myFeedUri, handleDataFeedVisit, handleError);
}
function getDataFeedCountry()
{
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date='+ getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:country' +
    '&metrics=ga:visits,ga:pageviews,ga:newVisits' +
    '&sort=ga:country' +
    '&ids=' + tableId;
	returnFunction = getDataFeedCountry;
	myService.getDataFeed(myFeedUri, handleDataFeedCountry, handleError);
}
function getDataFeedSystem()
{
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date='+ getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:browser,ga:browserVersion' +
    '&metrics=ga:visits' +
    '&sort=ga:browser' +
    '&ids=' + tableId;
	returnFunction = getDataFeedSystem;
	myService.getDataFeed(myFeedUri, handleDataFeedSystem, handleError);
}
function getDataFeesOS()
{
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date='+ getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:operatingSystem,ga:operatingSystemVersion' +
    '&metrics=ga:visits' +
    '&sort=ga:operatingSystem' +
    '&ids=' + tableId;
	returnFunction = getDataFeesOS;
	myService.getDataFeed(myFeedUri, handleDataFeedOS, handleError);
}
function getDataFeedScreen()
{
	var myFeedUri = 'https://www.google.com/analytics/feeds/data' +
    '?start-date='+ getStartDate() +
    '&end-date=' + getEndDate() +
    '&dimensions=ga:screenResolution' +
    '&metrics=ga:visits' +
    '&sort=ga:screenResolution' +
    '&ids=' + tableId;
	returnFunction = getDataFeedScreen;
	myService.getDataFeed(myFeedUri, handleDataFeedScreen, handleError);
}

/**
 * Handle the data returned by the Export API by constructing the 
 * inner parts of an HTML table and inserting into the HTML File.
 * @param {object} result Parameter passed back from the feed handler.
 */
 function handleDataFeedVisit(result)
 {
   // An array of analytics entries
  var entries = result.feed.entry;
	
  // create an HTML Table using an array of elements
  var outputTable = ['<table>'];
  outputTable.push('<tr>',
    '<th>Date</th>',
    '<th>Visits</th>',
    '<th>Pageviews</th>',
	'<th>New visitors</th>',
	'</tr>');

  // Iterate through the feed entries and add the data as table rows
  for (var i = 0; i < entries.length; i++) {
    var entry = entries[i];

    // add a row in the HTML Table array
    var row = [
      entry.getValueOf('ga:date'),
      entry.getValueOf('ga:visits'),
      entry.getValueOf('ga:pageviews'),
	  entry.getValueOf('ga:newVisits')
    ].join('</td><td>');
    outputTable.push('<tr><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // print the generated table
  document.getElementById('outputDiv').innerHTML = outputTable.join('');
 }
 
 function handleDataFeedSystem(result)
 {
   // An array of analytics entries
  var entries = result.feed.entry;
	
  // create an HTML Table using an array of elements
  var outputTable = ['<table>'];
  outputTable.push('<tr>',
	'<th>Browser</th>',
    '<th>Visitors</th>',
	'</tr>');

  // Iterate through the feed entries and add the data as table rows
  for (var i = 0; i < entries.length; i++) {
    var entry = entries[i];

    // add a row in the HTML Table array
    var row = [
	entry.getValueOf('ga:browser') + " " + entry.getValueOf('ga:browserVersion'),
      entry.getValueOf('ga:visits'),
    ].join('</td><td>');
    outputTable.push('<tr><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // print the generated table
  document.getElementById('outputDiv').innerHTML = outputTable.join('');
  
  getDataFeesOS();
 }
  function handleDataFeedOS(result)
 {
   // An array of analytics entries
  var entries = result.feed.entry;
	
  // create an HTML Table using an array of elements
  var outputTable = ['<table>'];
  outputTable.push('<tr>',
	'<th>Operatingsystem</th>',
    '<th>Visitors</th>',
	'</tr>');

  // Iterate through the feed entries and add the data as table rows
  for (var i = 0; i < entries.length; i++) {
    var entry = entries[i];

    // add a row in the HTML Table array
    var row = [
	entry.getValueOf('ga:operatingSystem') + " " + entry.getValueOf('ga:operatingSystemVersion'),
      entry.getValueOf('ga:visits'),
    ].join('</td><td>');
    outputTable.push('<tr><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // print the generated table
  document.getElementById('outputDiv').innerHTML += outputTable.join('');
  
  getDataFeedScreen();
 }
   function handleDataFeedScreen(result)
 {
   // An array of analytics entries
  var entries = result.feed.entry;
	
  // create an HTML Table using an array of elements
  var outputTable = ['<table>'];
  outputTable.push('<tr>',
	'<th>Screenresulotion</th>',
    '<th>Visitors</th>',
	'</tr>');

  // Iterate through the feed entries and add the data as table rows
  for (var i = 0; i < entries.length; i++) {
    var entry = entries[i];

    // add a row in the HTML Table array
    var row = [
	entry.getValueOf('ga:screenResolution'),
      entry.getValueOf('ga:visits'),
    ].join('</td><td>');
    outputTable.push('<tr><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // print the generated table
  document.getElementById('outputDiv').innerHTML += outputTable.join('');
 }
 
  function handleDataFeedCountry(result)
 {
   // An array of analytics entries
  var entries = result.feed.entry;
	
  // create an HTML Table using an array of elements
  var outputTable = ['<table>'];
  outputTable.push('<tr>',
	'<th>Country</th>',
    '<th>Visits</th>',
    '<th>Pageviews</th>',
	'<th>New visitors</th>',
	'</tr>');

  // Iterate through the feed entries and add the data as table rows
  for (var i = 0; i < entries.length; i++) {
    var entry = entries[i];

    // add a row in the HTML Table array
    var row = [
	entry.getValueOf('ga:country'),
      entry.getValueOf('ga:visits'),
      entry.getValueOf('ga:pageviews'),
	  entry.getValueOf('ga:newVisits')
    ].join('</td><td>');
    outputTable.push('<tr><td>', row, '</td></tr>');
  }
  outputTable.push('</table>');

  // print the generated table
  document.getElementById('outputDiv').innerHTML = outputTable.join('');
 }
 
function handleDataFeed(result) {
 
 // An array of Analytics feed entries.
 var entries = result.feed.getEntries();
 
 // Create an HTML Table using an array of elements.
 var outputTable = ['<table><tr>',
                    '<th>Page Title</th>',
                    '<th>Page Path</th>',
                    '<th>Pageviews</th></tr>'];

  // Iterate through the feed entries and add the data as table rows.
  for (var i = 0, entry; entry = entries[i]; ++i) {

     // Add a row in the HTML Table array.
     var row = [
       entry.getValueOf('ga:pageTitle'),
       entry.getValueOf('ga:pagePath'),
       entry.getValueOf('ga:pageviews')
     ].join('</td><td>');
     outputTable.push('<tr><td>', row, '</td></tr>');
   }
   outputTable.push('</table>');

  // Insert the table into the UI.
  document.getElementById('outputDiv').innerHTML =
      outputTable.join('');
}

/**
 * Alert any errors that come from the API request.
 * @param {object} e The error object returned by the Analytics API.
 */
function handleError(e) {
  var error = 'There was an error!\n';
  if (e.cause) {
    error += e.cause.status;
  } else {
    error.message;
  }
  alert(error);
}
